# Demonstration of pydantic-core unit tests running in the browser

To run tests in your browser, go
[here](https://githubproxy.samuelcolvin.workers.dev/samuelcolvin/pydantic-core/blob/main/wasm-preview/index.html).

If the output appears to stop prematurely, try looking in the developer console for more details.
